@@ -6,16 +6,16 @@
 # https://gitlab.com/msberends/AMR                                     #
 #                                                                      #
 # LICENCE                                                              #
-# (c) 2019 Berends MS (m.s.berends@umcg.nl), Luz CF (c.f.luz@umcg.nl)  #
+# (c) 2018-2020 Berends MS, Luz CF et al.                              #
 #                                                                      #
 # This R package is free software; you can freely use and distribute   #
 # it for both personal and commercial purposes under the terms of the  #
 # GNU General Public License version 2.0 (GNU GPL-2), as published by  #
 # the Free Software Foundation.                                        #
 #                                                                      #
-# This R package was created for academic research and was publicly    #
-# released in the hope that it will be useful, but it comes WITHOUT    #
-# ANY WARRANTY OR LIABILITY.                                           #
+# We created this package for both routine data analysis and academic  #
+# research and it was publicly released in the hope that it will be    #
+# useful, but it comes WITHOUT ANY WARRANTY OR LIABILITY.              #
 # Visit our website for more info: https://msberends.gitlab.io/AMR.    #
 # ==================================================================== #
 
@@ -25,6 +25,7 @@ globalVariables(c(".",
                   "ab_txt",
                   "abbreviations",
                   "antibiotic",
+                  "antibiotics",
                   "CNS_CPS",
                   "col_id",
                   "count",
@@ -35,6 +36,7 @@ globalVariables(c(".",
                   "first_isolate_row_index",
                   "fullname",
                   "fullname_lower",
+                  "g_species",
                   "genus",
                   "gramstain",
                   "group",
@@ -56,6 +58,7 @@ globalVariables(c(".",
                   "median",
                   "microorganisms",
                   "microorganisms.codes",
+                  "microorganisms.old",
                   "missing_names",
                   "mo",
                   "mono_count",
@@ -81,6 +84,7 @@ globalVariables(c(".",
                   "R",
                   "real_first_isolate",
                   "ref",
+                  "rsi_translation",
                   "rule_group",
                   "rule_name",
                   "S",
