@@ -1,11 +1,25 @@
-## ----setup, include = FALSE, results = 'markup'--------------------------
+## ----setup, include = FALSE, results = 'markup'-------------------------------
 knitr::opts_chunk$set(
   collapse = TRUE,
   comment = "#"
 )
 library(AMR)
 
-## ------------------------------------------------------------------------
+## ---- message = FALSE---------------------------------------------------------
+library(dplyr) # to support pipes: %>%
+
+## ---- results = 'hide'--------------------------------------------------------
+example_isolates %>% 
+  mdro() %>% 
+  freq() # show frequency table of the result
+
+## ---- echo = FALSE, results = 'asis', message = FALSE, warning = FALSE--------
+library(dplyr)
+example_isolates %>% 
+  mdro(info = FALSE) %>% 
+  freq() # show frequency table of the result
+
+## -----------------------------------------------------------------------------
 # a helper function to get a random vector with values S, I and R
 # with the probabilities 50% - 10% - 40%
 sample_rsi <- function() {
@@ -23,7 +37,7 @@ my_TB_data <- data.frame(rifampicin = sample_rsi(),
                          moxifloxacin = sample_rsi(),
                          kanamycin = sample_rsi())
 
-## ---- eval = FALSE-------------------------------------------------------
+## ---- eval = FALSE------------------------------------------------------------
 #  my_TB_data <- data.frame(RIF = sample_rsi(),
 #                           INH = sample_rsi(),
 #                           GAT = sample_rsi(),
@@ -32,15 +46,12 @@ my_TB_data <- data.frame(rifampicin = sample_rsi(),
 #                           MFX = sample_rsi(),
 #                           KAN = sample_rsi())
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 head(my_TB_data)
 
-## ------------------------------------------------------------------------
+## -----------------------------------------------------------------------------
 my_TB_data$mdr <- mdr_tb(my_TB_data)
 
-## ----lib clean, message = FALSE------------------------------------------
-library(clean)
-
-## ---- results = 'asis'---------------------------------------------------
+## ---- results = 'asis'--------------------------------------------------------
 freq(my_TB_data$mdr)
 
